==> ejc-sealm-impl-3.0.0-20220923.092521-122-sources.jar: com/ejianc/business/sealm/controller/ZcyysqController.java <==
package com.ejianc.business.sealm.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.sealm.api.IInstoreApi;
import com.ejianc.business.sealm.bean.ZcyysqEntity;
import com.ejianc.business.sealm.service.IZcyysqService;
import com.ejianc.business.sealm.vo.ZcyysqVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.api.IUserApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.usercenter.api.IThirdSystemApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 支出合同用印申请
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("zcyysq")
public class ZcyysqController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IInstoreApi instoreApi;

    @Autowired
    private IUserApi userApi;
    @Autowired
    private IThirdSystemApi thirdSystemApi;

    private static final String BILL_CODE = "ZCHTYY_CODE";//此处需要根据实际修改


    @Autowired
    private IZcyysqService service;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ZcyysqVO> saveOrUpdate(@RequestBody ZcyysqVO saveOrUpdateVO) {
    	ZcyysqEntity entity = BeanMapper.map(saveOrUpdateVO, ZcyysqEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
           //     entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
                entity.setXgcs(0);
                entity.setCreateUserName(sessionManager.getUserContext().getUserName());  //创建人
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        } else {
            entity.setUpdateUserName(sessionManager.getUserContext().getUserName());  //修改人
        }
    	service.saveOrUpdate(entity, false);
    	ZcyysqVO vo = BeanMapper.map(entity, ZcyysqVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ZcyysqVO> queryDetail(Long id) {
    	ZcyysqEntity entity = service.selectById(id);
    	ZcyysqVO vo = BeanMapper.map(entity, ZcyysqVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ZcyysqVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
//            for (ZcyysqVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
//                CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
//                if(!resp.isSuccess()){
//                    return CommonResponse.error("删除失败！"+resp.getMsg());
//                }
//            }
        }
        service.removeByIds(vos.stream().map(ZcyysqVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ZcyysqVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        fuzzyFields.add("billCode"); //单据编码
        fuzzyFields.add("htCode");  //合同编号
        fuzzyFields.add("yzName");  //印章名称
        fuzzyFields.add("createUserName");  //

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Parameter orgIdValue = param.getParams().get("orgId");
        Long orgId = orgIdValue == null || orgIdValue.getValue() == null ? InvocationInfoProxy.getOrgId() : Long.valueOf(String.valueOf(orgIdValue.getValue()));
        param.getParams().put("orgId", new Parameter(QueryParam.IN,
                iOrgApi.findChildrenByParentId(orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));



        IPage<ZcyysqEntity> page = service.queryPage(param,false);
        IPage<ZcyysqVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ZcyysqVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ZcyysqEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Zcyysq-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refZcyysqData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ZcyysqVO>> refZcyysqData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ZcyysqEntity> page = service.queryPage(param,false);
        IPage<ZcyysqVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ZcyysqVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     * @Description queryDetail 查询是否有该合同已经在审批中  billState=2,5
     * @param
     */
    @RequestMapping(value = "/queryBillState", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<Boolean> queryBillState(@RequestParam Long htId , @RequestParam String htCode) {
        QueryParam param = new QueryParam();

        param.getParams().put("billState",new Parameter(QueryParam.IN,
                Arrays.asList(new Integer[]{BillStateEnum.APPROVING_HAS_STATE.getBillStateCode(), BillStateEnum.APPROVING_UNEXAM_STATE.getBillStateCode()})
        ));
        param.getParams().put("htId", new Parameter(QueryParam.EQ, htId));
        param.getParams().put("htCode", new Parameter(QueryParam.EQ, htCode));
        param.getParams().put("dr", new Parameter(QueryParam.EQ, 0));

        List<ZcyysqEntity> zcyysqEntities = service.queryList(param);
        if (zcyysqEntities != null && zcyysqEntities.size() > 0){
            return CommonResponse.success("查询详情数据成功！",true);
        }else {
            return CommonResponse.success("查询详情数据成功！", false);
        }
    }

//    /**
//     * @Description 2.8 创建申请并授权接口
//     * @Return void
//     */
//    @RequestMapping(value = "/testQjyky", method = RequestMethod.GET)
//    @ResponseBody
//    public void testQjyky(Long id) {
//
////调用群杰接口，发送短信码
//        ZcyysqEntity zcyysqEntity = service.selectById(id);
//        YzsqSealOrderVo yzsqSealOrderVo = new YzsqSealOrderVo();
//        if (zcyysqEntity != null) {
//            if ("1472850976309252098".equals(zcyysqEntity.getYzlbId().toString())) {  //判断是印控仪才走下面的代码
//                // 请求url
//                String createUrl = PREFIX_URL + "order/addYZSQAndSealOrder";
//                String caseId =	zcyysqEntity.getId().toString();  //当前办理事项ID,默认是申请表code+id形式
//                String vertifyCode = YZMUtil.GenerateSafeCode();  //生成六位随机验证码
//                yzsqSealOrderVo.setWorkflowName("t_seal_zcyysq");  //表名
//                yzsqSealOrderVo.setCaseId(caseId);
//                yzsqSealOrderVo.setTitle("支出合同用印申请调永群杰验证码");
//                yzsqSealOrderVo.setFingerNo(zcyysqEntity.getCreateUserCode());  //授权人账号
//              //  yzsqSealOrderVo.setSealUserName(zcyysqEntity.getCreateUserName());  //实际用印人姓名
//                yzsqSealOrderVo.setFormNo(zcyysqEntity.getBillCode());  //流程单号
//                yzsqSealOrderVo.setVertifyCode(vertifyCode);
//            /*    yzsqSealOrderVo.setApplicantName(zcyysqEntity.getJbrName());  //申请人姓名
//                yzsqSealOrderVo.setDepName(zcyysqEntity.getOrgName());  //组织
//                yzsqSealOrderVo.setDescription(zcyysqEntity.getYyReason());  //用印事由
//                yzsqSealOrderVo.setPhoneNumber(zcyysqEntity.getJbrTel());  //经办人手机号
//                yzsqSealOrderVo.setIsTakeOut(zcyysqEntity.getSfWdgz().toString());  //是否外带公章,1是，0否*/
//                //子表信息封装
//                List<QjykyVO> qjykyVOList = new ArrayList<QjykyVO>();
//                QjykyVO qjykyVO = new QjykyVO();
//                qjykyVO.setSessionId(zcyysqEntity.getId().toString());  //授权明细ID
//                qjykyVO.setCaseId(caseId);
//                qjykyVO.setSealNo("20220407001");  //设备编码
//                qjykyVO.setSealCount(zcyysqEntity.getYycs());  //申请次数
//                qjykyVOList.add(qjykyVO);
//
//                yzsqSealOrderVo.setDetails(qjykyVOList);  //
//
//                // 转换为json字符串
//                String jsonString = JSONObject.toJSONString(yzsqSealOrderVo);
//                // 加密
//                byte[] resultStr = AESUtil.encrypt(jsonString, AESUtil.key);
//                // 发送请求
//                //String json = HttpUtil.post(createUrl, resultStr);
//                String json = AESUtil.http(createUrl, resultStr);
//                JSONObject jsonObject =JSONObject.parseObject(json);
//                String code = jsonObject.getString("errCode");
//                //判断是否调用成功，不成功就终结掉操作
//                if ("0".equals(code)) {
//                    zcyysqEntity.setYzm(vertifyCode);  //验证码发送成功后，将验证码同步到本地库
//                    service.updateById(zcyysqEntity);
//                } else {
//                    //打印报错
//                    logger.info(json);
//                    System.out.println(json);
//                }
//
//
//
//            }
//        }
//
//
//
//
//    }
}

==> ejc-sealm-impl-3.0.0-20230105.090228-130-sources.jar: com/ejianc/business/sealm/controller/ZcyysqController.java <==
package com.ejianc.business.sealm.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.sealm.api.IInstoreApi;
import com.ejianc.business.sealm.bean.ZcyysqEntity;
import com.ejianc.business.sealm.service.IZcyysqService;
import com.ejianc.business.sealm.vo.ZcyysqVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.api.IUserApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.usercenter.api.IThirdSystemApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 支出合同用印申请
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("zcyysq")
public class ZcyysqController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IInstoreApi instoreApi;

    @Autowired
    private IUserApi userApi;
    @Autowired
    private IThirdSystemApi thirdSystemApi;

    private static final String BILL_CODE = "ZCHTYY_CODE";//此处需要根据实际修改


    @Autowired
    private IZcyysqService service;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ZcyysqVO> saveOrUpdate(@RequestBody ZcyysqVO saveOrUpdateVO) {
    	ZcyysqEntity entity = BeanMapper.map(saveOrUpdateVO, ZcyysqEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
           //     entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
                entity.setXgcs(0);
                entity.setCreateUserName(sessionManager.getUserContext().getUserName());  //创建人
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        } else {
            entity.setUpdateUserName(sessionManager.getUserContext().getUserName());  //修改人
        }
    	service.saveOrUpdate(entity, false);
    	ZcyysqVO vo = BeanMapper.map(entity, ZcyysqVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ZcyysqVO> queryDetail(Long id) {
    	ZcyysqEntity entity = service.selectById(id);
    	ZcyysqVO vo = BeanMapper.map(entity, ZcyysqVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ZcyysqVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
//            for (ZcyysqVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
//                CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
//                if(!resp.isSuccess()){
//                    return CommonResponse.error("删除失败！"+resp.getMsg());
//                }
//            }
        }
        service.removeByIds(vos.stream().map(ZcyysqVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ZcyysqVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        fuzzyFields.add("billCode"); //单据编码
        fuzzyFields.add("htCode");  //合同编号
        fuzzyFields.add("yzName");  //印章名称
        fuzzyFields.add("createUserName");  //

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Parameter orgIdValue = param.getParams().get("orgId");
        Long orgId = orgIdValue == null || orgIdValue.getValue() == null ? InvocationInfoProxy.getOrgId() : Long.valueOf(String.valueOf(orgIdValue.getValue()));
        param.getParams().put("orgId", new Parameter(QueryParam.IN,
                iOrgApi.findChildrenByParentId(orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));



        IPage<ZcyysqEntity> page = service.queryPage(param,false);
        IPage<ZcyysqVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ZcyysqVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ZcyysqEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Zcyysq-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refZcyysqData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ZcyysqVO>> refZcyysqData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ZcyysqEntity> page = service.queryPage(param,false);
        IPage<ZcyysqVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ZcyysqVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     * @Description queryDetail 查询是否有该合同已经在审批中  billState=2,5
     * @param
     */
    @RequestMapping(value = "/queryBillState", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<Boolean> queryBillState(@RequestParam Long htId , @RequestParam String htCode) {
        QueryParam param = new QueryParam();

        param.getParams().put("billState",new Parameter(QueryParam.IN,
                Arrays.asList(new Integer[]{BillStateEnum.APPROVING_HAS_STATE.getBillStateCode(), BillStateEnum.APPROVING_UNEXAM_STATE.getBillStateCode()})
        ));
        param.getParams().put("htId", new Parameter(QueryParam.EQ, htId));
        param.getParams().put("htCode", new Parameter(QueryParam.EQ, htCode));
        param.getParams().put("dr", new Parameter(QueryParam.EQ, 0));

        List<ZcyysqEntity> zcyysqEntities = service.queryList(param);
        if (zcyysqEntities != null && zcyysqEntities.size() > 0){
            return CommonResponse.success("查询详情数据成功！",true);
        }else {
            return CommonResponse.success("查询详情数据成功！", false);
        }
    }


    /**
     * @Description queryNumByHtId 根据合同id查找单据
     * @param id
     */
    @RequestMapping(value = "/queryNumByHtId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<Boolean> queryNumByHtId(@RequestParam Long htId , @RequestParam String htCode) {
        QueryParam param = new QueryParam();

        param.getParams().put("billState",new Parameter(QueryParam.IN,
                Arrays.asList(new Integer[]{BillStateEnum.APPROVING_HAS_STATE.getBillStateCode(),
                        BillStateEnum.APPROVING_UNEXAM_STATE.getBillStateCode(),
                        BillStateEnum.COMMITED_STATE.getBillStateCode(),
                        BillStateEnum.PASSED_STATE.getBillStateCode()
                })
        ));
        param.getParams().put("htId", new Parameter(QueryParam.EQ, htId));
        param.getParams().put("htCode", new Parameter(QueryParam.EQ, htCode));
        param.getParams().put("dr", new Parameter(QueryParam.EQ, 0));

        List<ZcyysqEntity> zcyysqEntities = service.queryList(param);
        if (zcyysqEntities != null && zcyysqEntities.size() > 0){
            return CommonResponse.success("查询详情数据成功！",true);
        }else {
            return CommonResponse.success("查询详情数据成功！", false);
        }
    }
//    /**
//     * @Description 2.8 创建申请并授权接口
//     * @Return void
//     */
//    @RequestMapping(value = "/testQjyky", method = RequestMethod.GET)
//    @ResponseBody
//    public void testQjyky(Long id) {
//
////调用群杰接口，发送短信码
//        ZcyysqEntity zcyysqEntity = service.selectById(id);
//        YzsqSealOrderVo yzsqSealOrderVo = new YzsqSealOrderVo();
//        if (zcyysqEntity != null) {
//            if ("1472850976309252098".equals(zcyysqEntity.getYzlbId().toString())) {  //判断是印控仪才走下面的代码
//                // 请求url
//                String createUrl = PREFIX_URL + "order/addYZSQAndSealOrder";
//                String caseId =	zcyysqEntity.getId().toString();  //当前办理事项ID,默认是申请表code+id形式
//                String vertifyCode = YZMUtil.GenerateSafeCode();  //生成六位随机验证码
//                yzsqSealOrderVo.setWorkflowName("t_seal_zcyysq");  //表名
//                yzsqSealOrderVo.setCaseId(caseId);
//                yzsqSealOrderVo.setTitle("支出合同用印申请调永群杰验证码");
//                yzsqSealOrderVo.setFingerNo(zcyysqEntity.getCreateUserCode());  //授权人账号
//              //  yzsqSealOrderVo.setSealUserName(zcyysqEntity.getCreateUserName());  //实际用印人姓名
//                yzsqSealOrderVo.setFormNo(zcyysqEntity.getBillCode());  //流程单号
//                yzsqSealOrderVo.setVertifyCode(vertifyCode);
//            /*    yzsqSealOrderVo.setApplicantName(zcyysqEntity.getJbrName());  //申请人姓名
//                yzsqSealOrderVo.setDepName(zcyysqEntity.getOrgName());  //组织
//                yzsqSealOrderVo.setDescription(zcyysqEntity.getYyReason());  //用印事由
//                yzsqSealOrderVo.setPhoneNumber(zcyysqEntity.getJbrTel());  //经办人手机号
//                yzsqSealOrderVo.setIsTakeOut(zcyysqEntity.getSfWdgz().toString());  //是否外带公章,1是，0否*/
//                //子表信息封装
//                List<QjykyVO> qjykyVOList = new ArrayList<QjykyVO>();
//                QjykyVO qjykyVO = new QjykyVO();
//                qjykyVO.setSessionId(zcyysqEntity.getId().toString());  //授权明细ID
//                qjykyVO.setCaseId(caseId);
//                qjykyVO.setSealNo("20220407001");  //设备编码
//                qjykyVO.setSealCount(zcyysqEntity.getYycs());  //申请次数
//                qjykyVOList.add(qjykyVO);
//
//                yzsqSealOrderVo.setDetails(qjykyVOList);  //
//
//                // 转换为json字符串
//                String jsonString = JSONObject.toJSONString(yzsqSealOrderVo);
//                // 加密
//                byte[] resultStr = AESUtil.encrypt(jsonString, AESUtil.key);
//                // 发送请求
//                //String json = HttpUtil.post(createUrl, resultStr);
//                String json = AESUtil.http(createUrl, resultStr);
//                JSONObject jsonObject =JSONObject.parseObject(json);
//                String code = jsonObject.getString("errCode");
//                //判断是否调用成功，不成功就终结掉操作
//                if ("0".equals(code)) {
//                    zcyysqEntity.setYzm(vertifyCode);  //验证码发送成功后，将验证码同步到本地库
//                    service.updateById(zcyysqEntity);
//                } else {
//                    //打印报错
//                    logger.info(json);
//                    System.out.println(json);
//                }
//
//
//
//            }
//        }
//
//
//
//
//    }
}
